pub enum AddSeedMode {
IKM(Ikm),
Wrapped(WrappedSeed),
}Expand description
Specifies how PSK seeds are provided when joining teams.
Teams share a single PSK seed that is used to derive Pre-Shared Keys (PSKs) for QUIC connections between team members.
This type will be removed soon since certificates will be used instead of PSKs in the future.
Variants
IKM(Ikm)
Provides raw input key material to derive a seed.
The IKM must be exactly 32 bytes. This mode is available in both:
create_team: Allows team owners to specify deterministic seed materialadd_team: Allows non-owners to join using pre-shared key material
Wrapped(WrappedSeed)
Provides an encrypted seed for secure distribution.
Used by non-owners in the add_team API to join an existing team.
Seeds are wrapped (encrypted) to prevent plaintext exposure during
the join process.