pub enum ChanOp {
RecvOnly,
SendOnly,
SendRecv,
}Expand description
Valid channel operations for a label assignment.
Variants
RecvOnly
The device can only receive data in channels with this label.
SendOnly
The device can only send data in channels with this label.
SendRecv
The device can send or receive data in channels with this label.