#[non_exhaustive]#[repr(u16)]pub enum CipherSuiteId {
TlsAes128GcmSha256 = 275,
TlsAes256GcmSha384 = 531,
TlsChaCha20Poly1305Sha256 = 787,
TlsAes128CcmSha256 = 1_043,
TlsAes128Ccm8Sha256 = 1_299,
}Expand description
A TLS 1.3 cipher suite.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TlsAes128GcmSha256 = 275
TLS_AES_128_GCM_SHA256
TlsAes256GcmSha384 = 531
TLS_AES_256_GCM_SHA384
TlsChaCha20Poly1305Sha256 = 787
TLS_CHACHA20_POLY1305_SHA256
TlsAes128CcmSha256 = 1_043
TLS_AES_128_CCM_SHA256
TlsAes128Ccm8Sha256 = 1_299
TLS_AES_128_CCM_8_SHA256
Implementations
Sourceimpl CipherSuiteId
impl CipherSuiteId
Sourcepub const fn all() -> &'static [CipherSuiteId]
pub const fn all() -> &'static [CipherSuiteId]
Returns all of the cipher suites.
Sourcepub const fn to_bytes(self) -> [u8; 2]
pub const fn to_bytes(self) -> [u8; 2]
Converts the cipher suite to its (big endian) byte representation.
Sourcepub const fn try_from_bytes(bytes: [u8; 2]) -> Option<CipherSuiteId>
pub const fn try_from_bytes(bytes: [u8; 2]) -> Option<CipherSuiteId>
Attempts to create a cipher suite from its (big endian) byte representation.
It returns None if bytes is not a valid cipher suite.