pub enum CreateSeedMode {
Generate,
IKM(Ikm),
}Expand description
Specifies how PSK seeds are provided when creating a new team.
Teams share a single PSK seed that is used to derive Pre-Shared Keys (PSKs) for QUIC connections between team members.
This type will be removed soon since certificates will be used instead of PSKs in the future.
Variants
Generate
Generates a new random seed.
Used by team owners in the create_team API when establishing a new team.
IKM(Ikm)
Provides raw input key material to derive a seed.
The IKM must be exactly 32 bytes. This mode is available in both:
create_team: Allows team owners to specify deterministic seed materialadd_team: Allows non-owners to join using pre-shared key material