pub struct SyncPeerConfig {
pub interval: Option<Duration>,
pub sync_now: bool,
}Expand description
Configuration values for syncing with a peer
Fields
interval: Option<Duration>The interval at which syncing occurs. If None, the peer will not be periodically synced.
sync_now: boolDetermines whether the peer will be scheduled for an immediate sync when added.