DaemonApiClient

Struct DaemonApiClient 

pub struct DaemonApiClient<Stub = Channel<DaemonApiRequest, DaemonApiResponse>>(/* private fields */);
The client stub that makes RPC calls to the server. All request methods return Futures.

Implementations

Source

impl DaemonApiClient

pub fn new<T>( config: Config, transport: T, ) -> NewClient<Self, RequestDispatch<DaemonApiRequest, DaemonApiResponse, T>>

Returns a new client stub that sends requests over the given transport.

Source

impl<Stub> DaemonApiClient<Stub>
where Stub: Stub<Req = DaemonApiRequest, Resp = DaemonApiResponse>,

pub fn version( &self, ctx: Context, ) -> impl Future<Output = Result<Result<Version>, RpcError>> + '_

Returns the daemon’s version.

pub fn aranya_local_addr( &self, ctx: Context, ) -> impl Future<Output = Result<Result<Addr>, RpcError>> + '_

Gets local address the Aranya sync server is bound to.

pub fn get_key_bundle( &self, ctx: Context, ) -> impl Future<Output = Result<Result<KeyBundle>, RpcError>> + '_

Gets the public key bundle for this device

pub fn get_device_id( &self, ctx: Context, ) -> impl Future<Output = Result<Result<DeviceId>, RpcError>> + '_

Gets the public device id.

pub fn add_sync_peer( &self, ctx: Context, addr: Addr, team: TeamId, config: SyncPeerConfig, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Adds the peer for automatic periodic syncing.

pub fn sync_now( &self, ctx: Context, addr: Addr, team: TeamId, cfg: Option<SyncPeerConfig>, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Sync with peer immediately.

pub fn remove_sync_peer( &self, ctx: Context, addr: Addr, team: TeamId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Removes the peer from automatic syncing.

pub fn add_team( &self, ctx: Context, cfg: AddTeamConfig, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

add a team to the local device store that was created by someone else. Not an aranya action/command.

pub fn remove_team( &self, ctx: Context, team: TeamId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Remove a team from local device storage.

pub fn create_team( &self, ctx: Context, cfg: CreateTeamConfig, ) -> impl Future<Output = Result<Result<TeamId>, RpcError>> + '_

Create a new graph/team with the current device as the owner.

pub fn close_team( &self, ctx: Context, team: TeamId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Close the team.

pub fn encrypt_psk_seed_for_peer( &self, ctx: Context, team: TeamId, peer_enc_pk: EncryptionPublicKey<CS>, ) -> impl Future<Output = Result<Result<WrappedSeed>, RpcError>> + '_

Encrypts the team’s syncing PSK(s) for the peer.

pub fn add_device_to_team( &self, ctx: Context, team: TeamId, keys: KeyBundle, initial_role: Option<RoleId>, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Adds a device to the team with optional initial roles.

pub fn remove_device_from_team( &self, ctx: Context, team: TeamId, device: DeviceId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Remove device from the team.

pub fn devices_on_team( &self, ctx: Context, team: TeamId, ) -> impl Future<Output = Result<Result<Box<[DeviceId]>>, RpcError>> + '_

Returns all the devices on the team.

pub fn device_keybundle( &self, ctx: Context, team: TeamId, device: DeviceId, ) -> impl Future<Output = Result<Result<KeyBundle>, RpcError>> + '_

Returns the device’s key bundle.

pub fn setup_default_roles( &self, ctx: Context, team: TeamId, owning_role: RoleId, ) -> impl Future<Output = Result<Result<Box<[Role]>>, RpcError>> + '_

Configures the team with default roles from policy.

It returns the default roles that were created.

pub fn team_roles( &self, ctx: Context, team: TeamId, ) -> impl Future<Output = Result<Result<Box<[Role]>>, RpcError>> + '_

Returns the current team roles.

pub fn role_owners( &self, ctx: Context, team: TeamId, role: RoleId, ) -> impl Future<Output = Result<Result<Box<[Role]>>, RpcError>> + '_

Returns the roles that own the target role.

pub fn assign_role( &self, ctx: Context, team: TeamId, device: DeviceId, role: RoleId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Assign a role to a device.

pub fn revoke_role( &self, ctx: Context, team: TeamId, device: DeviceId, role: RoleId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Revoke a role from a device.

pub fn change_role( &self, ctx: Context, team: TeamId, device: DeviceId, old_role: RoleId, new_role: RoleId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Changes the assigned role of a device.

pub fn device_role( &self, ctx: Context, team: TeamId, device: DeviceId, ) -> impl Future<Output = Result<Result<Option<Role>>, RpcError>> + '_

Returns the role assigned to the device.

pub fn create_label( &self, ctx: Context, team: TeamId, name: Text, managing_role_id: RoleId, ) -> impl Future<Output = Result<Result<LabelId>, RpcError>> + '_

Create a label.

pub fn delete_label( &self, ctx: Context, team: TeamId, label_id: LabelId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Delete a label.

pub fn label( &self, ctx: Context, team: TeamId, label: LabelId, ) -> impl Future<Output = Result<Result<Option<Label>>, RpcError>> + '_

Returns a specific label.

pub fn labels( &self, ctx: Context, team: TeamId, ) -> impl Future<Output = Result<Result<Vec<Label>>, RpcError>> + '_

Returns all labels on the team.

pub fn add_label_managing_role( &self, ctx: Context, team: TeamId, label_id: LabelId, managing_role_id: RoleId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

pub fn assign_label_to_device( &self, ctx: Context, team: TeamId, device: DeviceId, label: LabelId, op: ChanOp, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Assigns a label to a device.

pub fn revoke_label_from_device( &self, ctx: Context, team: TeamId, device: DeviceId, label: LabelId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Revokes a label from a device.

pub fn labels_assigned_to_device( &self, ctx: Context, team: TeamId, device: DeviceId, ) -> impl Future<Output = Result<Result<Box<[Label]>>, RpcError>> + '_

Returns all labels assigned to the device.

pub fn afc_shm_info( &self, ctx: Context, ) -> impl Future<Output = Result<Result<AfcShmInfo>, RpcError>> + '_

Available on crate feature afc only.

Gets AFC shared-memory configuration info.

pub fn create_afc_channel( &self, ctx: Context, team: TeamId, peer_id: DeviceId, label_id: LabelId, ) -> impl Future<Output = Result<Result<AfcSendChannelInfo>, RpcError>> + '_

Available on crate feature afc only.

Create a send-only AFC channel.

pub fn delete_afc_channel( &self, ctx: Context, chan: AfcLocalChannelId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Available on crate feature afc only.

Delete a AFC channel.

pub fn accept_afc_channel( &self, ctx: Context, team: TeamId, ctrl: AfcCtrl, ) -> impl Future<Output = Result<Result<AfcReceiveChannelInfo>, RpcError>> + '_

Available on crate feature afc only.

Accept a receive-only AFC channel by processing a peer’s ctrl message.