aranya_daemon_api

Struct DaemonApiClient

source
pub struct DaemonApiClient<Stub = Channel<DaemonApiRequest, DaemonApiResponse>>(/* private fields */);
The client stub that makes RPC calls to the server. All request methods return Futures.

Implementations

source

impl DaemonApiClient

source

pub fn new<T>( config: Config, transport: T, ) -> NewClient<Self, RequestDispatch<DaemonApiRequest, DaemonApiResponse, T>>

Returns a new client stub that sends requests over the given transport.

source

impl<Stub> DaemonApiClient<Stub>
where Stub: Stub<Req = DaemonApiRequest, Resp = DaemonApiResponse>,

source

pub fn initialize( &self, ctx: Context, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn get_key_bundle( &self, ctx: Context, ) -> impl Future<Output = Result<Result<KeyBundle>, RpcError>> + '_

Gets the public key bundle for this device

source

pub fn get_device_id( &self, ctx: Context, ) -> impl Future<Output = Result<Result<DeviceId>, RpcError>> + '_

Gets the public device id.

source

pub fn add_sync_peer( &self, ctx: Context, addr: Addr, team: TeamId, interval: Duration, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Adds the peer for automatic periodic syncing.

source

pub fn remove_sync_peer( &self, ctx: Context, addr: Addr, team: TeamId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

Removes the peer from automatic syncing.

source

pub fn add_team( &self, ctx: Context, team: TeamId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

add a team to the local device store that was created by someone else. Not an aranya action/command.

source

pub fn remove_team( &self, ctx: Context, team: TeamId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

remove a team from the local device store.

source

pub fn create_team( &self, ctx: Context, ) -> impl Future<Output = Result<Result<TeamId>, RpcError>> + '_

Create a new graph/team with the current device as the owner.

source

pub fn close_team( &self, ctx: Context, team: TeamId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn add_device_to_team( &self, ctx: Context, team: TeamId, keys: KeyBundle, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn remove_device_from_team( &self, ctx: Context, team: TeamId, device: DeviceId, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn assign_role( &self, ctx: Context, team: TeamId, device: DeviceId, role: Role, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn revoke_role( &self, ctx: Context, team: TeamId, device: DeviceId, role: Role, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn assign_net_name( &self, ctx: Context, team: TeamId, device: DeviceId, name: NetIdentifier, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn remove_net_name( &self, ctx: Context, team: TeamId, device: DeviceId, name: NetIdentifier, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn create_label( &self, ctx: Context, team: TeamId, label: Label, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn delete_label( &self, ctx: Context, team: TeamId, label: Label, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn assign_label( &self, ctx: Context, team: TeamId, device: DeviceId, label: Label, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn revoke_label( &self, ctx: Context, team: TeamId, device: DeviceId, label: Label, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_

source

pub fn create_channel( &self, ctx: Context, team: TeamId, peer: NetIdentifier, label: Label, ) -> impl Future<Output = Result<Result<(ChannelId, NodeId, AfcCtrl)>, RpcError>> + '_

source

pub fn delete_channel( &self, ctx: Context, chan: ChannelId, ) -> impl Future<Output = Result<Result<AfcCtrl>, RpcError>> + '_

source

pub fn receive_afc_ctrl( &self, ctx: Context, ctrl: AfcCtrl, ) -> impl Future<Output = Result<Result<()>, RpcError>> + '_